import * as path from "path";
import * as _fs from "fs";
import { createGenerator } from "ts-json-schema-generator";
const fs = _fs.promises;
export async function generateValidator({ cwd, validatorGenerator, tsconfigFilePath, filePath, extraTags = [], sortProps, strictTuples, skipTypeCheck = true, encodeRefs, additionalProperties = false }) {
    const absoluteFilePath = path.resolve(cwd, filePath);
    const parentFileDir = path.dirname(path.resolve(cwd, filePath));
    const fileName = path.basename(absoluteFilePath, ".ts");
    const apiTypesCode = await fs.readFile(filePath, "utf-8");
    try {
        const config = {
            path: absoluteFilePath,
            tsconfig: tsconfigFilePath,
            type: "*",
            skipTypeCheck: skipTypeCheck !== null && skipTypeCheck !== void 0 ? skipTypeCheck : true,
            additionalProperties: additionalProperties !== null && additionalProperties !== void 0 ? additionalProperties : false,
            sortProps: sortProps,
            strictTuples: strictTuples,
            encodeRefs: encodeRefs,
            extraTags: extraTags
        };
        const generator = createGenerator(config);
        const schema = generator.createSchema(config.type);
        if (!schema) {
            console.warn("No schema: " + filePath);
            return;
        }
        const validatorFilePath = path.join(parentFileDir, fileName + ".validator.ts");
        const validator = validatorGenerator({
            apiFileCode: apiTypesCode,
            apiFilePath: absoluteFilePath,
            validatorFilePath,
            schema
        });
        return {
            validatorFilePath: validatorFilePath,
            code: validator
        };
    }
    catch (error) {
        console.error("Fail to parse: " + filePath, error);
        throw error;
    }
}
//# sourceMappingURL=create-validator-ts.js.map